==> haskell-crypto-random-0.0.9-90-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
key: crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
abi: d3b3dab7ac34ace5e180b14d9d3b1cfe
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
                Crypto.Random.Entropy.RDRand
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    securemem-0.1.10-H7YnVeCGypR5G2txPG5sst unix-2.7.2.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-random-0.0.9-106-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-random.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-random
version: 0.0.9
id: crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H
key: crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: http://github.com/vincenthz/hs-crypto-random
synopsis: Simple cryptographic random related types
description:
    Simple cryptographic random related types
category: Cryptography
abi: f74526fc636004960a4fed4cbc1edf52
exposed: True
exposed-modules:
    Crypto.Random Crypto.Random.API Crypto.Random.Test
hidden-modules: Crypto.Random.Generator Crypto.Random.Entropy
                Crypto.Random.Entropy.Source Crypto.Random.Entropy.Unix
                Crypto.Random.Entropy.RDRand
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-random-0.0.9
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-random-0.0.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-random-0.0.9
hs-libraries: HScrypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    securemem-0.1.10-AgRbjRbsMHcJeKnVmNGCBY unix-2.7.2.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-crypto-random/html/crypto-random.haddock
haddock-html: /usr/share/doc/haskell-crypto-random/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
